from ...imports import *

def getRunner(self,layout=None):

    runner_page = QWidget()
    runner_layout = layout or QVBoxLayout(runner_page)
    top = QHBoxLayout()
    top.addWidget(QLabel("User:"))
    top.addWidget(self.user_in, 2)
    top.addWidget(QLabel("Path:"))
    top.addWidget(self.path_in, 3)
    top.addWidget(self.run_btn)
    top.addWidget(self.rerun_btn)
    top.addWidget(self.clear_btn)
    layout.addLayout(top)


    top = QHBoxLayout()
    top.addWidget(QLabel("User:"))
    top.addWidget(self.user_in, 2)
    top.addWidget(QLabel("Path:"))
    top.addWidget(self.path_in, 3)
    top.addWidget(self.run_btn)
    top.addWidget(self.rerun_btn)
    top.addWidget(self.clear_btn)
    layout.addLayout(top)


    filter_row = QHBoxLayout()
    filter_row.addWidget(QLabel("Log Output:"))
    filter_row.addStretch(1)
    filter_row.addWidget(self.rb_all)
    filter_row.addWidget(self.rb_err)
    filter_row.addWidget(self.rb_wrn)
    filter_row.addWidget(self.cb_try_alt_ext)
    runner_layout.addLayout(filter_row)

    layout.addWidget(self.log_view, 3)

    left  = getListBox((self.errors_list,   "Errors (file:line:col):", 1))
    right = getListBox((self.warnings_list, "Warnings (file:line:col):", 1))
    lists_row = getRow(left, right)
    layout.addLayout(lists_row, 2)

    tabs.addTab(runner_page, "Runner")



#!/usr/bin/env python3
import os
import sys
import traceback
from typing import *
from dataclasses import dataclass

# Keep your project search-path extension if you need it:
# sys.path.append("/path/to/project_root")

# Keep abstract_* as-is per your preference
from abstract_paths import (
    findContent, findContentAndEdit,
    get_directory_map, findGlobFiles, collect_filepaths,
    define_defaults, get_py_script_paths
)

# ✅ Qt6 imports
from PyQt6.QtCore import Qt, QThread, pyqtSignal
from PyQt6.QtWidgets import (
    QApplication, QWidget, QVBoxLayout, QHBoxLayout, QGridLayout, QTabWidget,
    QLabel, QLineEdit, QPushButton, QTextEdit, QListWidget, QListWidgetItem,
    QCheckBox, QFileDialog, QSpinBox, QMessageBox
)
from PyQt6.QtGui import QTextCursor



from .functions import *
def set_search_params(self, params):  # ← IDE will call this
    try:
        """params is your FinderTab SearchParams (directory + filters)."""
        self._params = params
        # reflect directory in the input for clarity:
        if getattr(params, "directory", None):
            self.file_in.setText(params.directory)
    except Exception as e:
        logger.info(f"set_search_params: {e}")
def browse_file(self):
    try:
        # pick a project root directory
        d = QFileDialog.getExistingDirectory(self, "Select Project Root")
        if d:
            self.file_in.setText(d)
    except Exception as e:
        logger.info(f"browse_file: {e}")
def preview_patch(self):
    # Prefer FinderTab-provided params if present
    try:
        p = getattr(self, "_params", None)

        root = (p.directory if p and getattr(p, "directory", None) else self.file_in.text().strip())
        if not root or not os.path.isdir(root):
            QMessageBox.critical(self, "Error", "Invalid project root.")
            return

        diff = self.diff_text.toPlainText().strip()
        if not diff:
            QMessageBox.critical(self, "Error", "No diff provided.")
            return

        # Gather filters from SearchParams if available, else fall back to simple defaults
        kwargs = {}
        if p:
            kwargs = dict(
                allowed_exts=p.allowed_exts,
                unallowed_exts=p.unallowed_exts,
                exclude_types=p.exclude_types,
                exclude_dirs=p.exclude_dirs,
                exclude_patterns=p.exclude_patterns,
                add=p.add,
                recursive=p.recursive,
            )
        else:
            kwargs = dict(exclude_dirs=["node_modules", "__pycache__"])
    except Exception as e:
        logger.info(f"Error: {e!r}")#QMessageBox.critical(self, "Prefer FinderTab-provided params if present", f"{e!r}")
    try:
        previews = plan_previews(
            diff,
            directory=root,
            **kwargs,  # ← pass Finder filters through
        )
        if not previews:
            QMessageBox.information(self, "No Matches", "No targets found for this diff.")
            self.preview.clear()
            self._previews = {}
            return

        # stash for save
        self._previews = previews

        # render a simple multi-file preview
        chunks: List[str] = []
        for fp in sorted(previews.keys()):
            chunks.append(f"=== {fp} ===")
            chunks.append(previews[fp])
        self.preview.setPlainText("\n".join(chunks))

    except Exception as e:
        logger.info(f"Error: {e!r}")#QMessageBox.critical(self, "Error", f"{e!r}")

def save_patch(self):
    if not hasattr(self, "_previews") or not self._previews:
        QMessageBox.warning(self, "Warning", "Nothing to save. Generate a preview first.")
        return
    changed = 0
    try:
        for fp, text in self._previews.items():
            # one-time backup per file
            bak = fp + ".bak"
            if not os.path.exists(bak):
                try: shutil.copyfile(fp, bak)
                except Exception: pass
            write_text_atomic(fp, text if text.endswith("\n") else text + "\n")
            changed += 1
        QMessageBox.information(self, "Success", f"Saved {changed} file(s).")
    except Exception as e:
        logger.info(f"Error: {e!r}")#QMessageBox.critical(self, "Error", f"Failed to save: {e!r}")



from .mainFuncs import *
def initFuncs(self):
    try:
        self.set_search_params = set_search_params
        self.browse_file = browse_file
        self.preview_patch = preview_patch
        self.save_patch = save_patch
        return self
    except Exception as e:
        logger.info(f"Approve save: {e}")



from .collectFilesTab import collectFilesTab
from .diffParserTab import diffParserTab
from .directoryMapTab import directoryMapTab
from .extractImportsTab import extractImportsTab
from .finderTab import finderTab
from .finderConsole import finderConsole
from abstract_gui.QT6 import QApplication,sys
import traceback
def startFinderConsole():
    try:
        app = QApplication(sys.argv)
        win = finderConsole()
        win.show()
        sys.exit(app.exec())
    except Exception:
        print(traceback.format_exc())



from ..functions import *
from .initFuncs import initFuncs
# New Tab: Directory Map
# New Tab: Collect Files
class collectFilesTab(QWidget):
    def __init__(self):
        super().__init__()
        self.setLayout(QVBoxLayout())
        grid = QGridLayout()
        # Directory picker
        self.dir_in = QLineEdit(os.getcwd())
        btn_browse = QPushButton("Browse…")
        btn_browse.clicked.connect(self.browse_dir)
        # Extensions (comma-separated)
        self.exts_in = QLineEdit("ts,tsx,js,jsx,css")
        self.exts_in.setPlaceholderText("ts,tsx,js,jsx,css")
        # Optional: restrict to a sub-path (regex or boolean True)
        self.paths_in = QLineEdit("")
        self.paths_in.setPlaceholderText("True (all) or regex like ^src/")
        # Flags
        self.chk_recursive = QCheckBox("Recursive"); self.chk_recursive.setChecked(True)
        # Run + Open in editor
        self.btn_run = QPushButton("Collect Files")
        self.btn_run.clicked.connect(self.start_collect)
        self.btn_open_all = QPushButton("Open all files in VS Code")
        self.btn_open_all.clicked.connect(self.open_all_hits)
        self.btn_open_all.setEnabled(False)
        # Layout form
        r = 0
        grid.addWidget(QLabel("Directory"), r, 0); grid.addWidget(self.dir_in, r, 1); grid.addWidget(btn_browse, r, 2); r+=1
        grid.addWidget(QLabel("Extensions"),r, 0); grid.addWidget(self.exts_in, r, 1, 1, 2); r+=1
        grid.addWidget(QLabel("Paths"), r, 0); grid.addWidget(self.paths_in, r, 1, 1, 2); r+=1
        flag_row = QHBoxLayout()
        flag_row.addWidget(self.chk_recursive)
        grid.addLayout(flag_row, r, 0, 1, 3); r+=1
        self.layout().addLayout(grid)
        cta = QHBoxLayout()
        cta.addWidget(self.btn_run)
        cta.addStretch(1)
        cta.addWidget(self.btn_open_all)
        self.layout().addLayout(cta)
        # Output area
        self.log = QTextEdit()
        self.log.setReadOnly(True)
        self.log.setLineWrapMode(QTextEdit.LineWrapMode.NoWrap)
        self.layout().addWidget(QLabel("Results"))
        self.layout().addWidget(self.log, stretch=2)
        self.list = QListWidget()
        self.list.itemDoubleClicked.connect(self.open_one)
        self.layout().addWidget(self.list, stretch=3)
        self._last_results = []


collectFilesTab = initFuncs(collectFilesTab)
